.. title:: crumbs

crumbs
======

Generalized all-in-one parameters.  Get configuration through a single interface
from configuration files, environment variables, and command line arguments.

.. toctree::
   :titlesonly:

   getting_started
   parameters

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
